@@ -14,6 +14,7 @@ from types import TracebackType
 from typing import Any, Dict, List, Optional
 
 import libsbml
+from typing_extensions import Self, TypeAlias
 
 from .utils import convert_id_to_sbml, warning_on_one_line
 
@@ -62,9 +63,9 @@ class BaseModel(ABC):
             default_meta_info.update(meta_info)
         self.meta_info: Dict[str, Any] = {"model": Model(**default_meta_info)}
         self._ids: set[str] = set()
-        self._copy = None
+        self._copy: BaseModel | None = None
 
-    def __enter__(self) -> Any:
+    def __enter__(self) -> Self:  # type: ignore
         """Enter the context manager.
 
         Returns
@@ -84,9 +85,10 @@ class BaseModel(ABC):
 
         Restores any changes made to the model structure.
         """
-        self.__dict__ = self._copy.__dict__
+        if self._copy is not None:
+            self.__dict__ = self._copy.__dict__
 
-    def copy(self) -> Any:
+    def copy(self) -> Self:  # type: ignore
         """Create a deepcopy of the model.
 
         Returns
@@ -94,7 +96,7 @@ class BaseModel(ABC):
         model
             Deepcopy of the model object
         """
-        return copy.deepcopy(self)
+        return copy.deepcopy(self)  # type: ignore
 
     def _check_for_existence(
         self,
